Site
=================


.. autoclass:: shephard.site.Site


Site properties
................
.. autofunction:: shephard.site.Site.residue
.. autofunction:: shephard.site.Site.position
.. autofunction:: shephard.site.Site.protein
.. autofunction:: shephard.site.Site.site_type
.. autofunction:: shephard.site.Site.symbol
.. autofunction:: shephard.site.Site.value


Site sequence functions
............................
.. autofunction:: shephard.site.Site.get_local_sequence_context


Domain Attribute Functions
...........................
.. autofunction:: shephard.site.Site.attributes
.. autofunction:: shephard.site.Site.attribute
.. autofunction:: shephard.site.Site.add_attribute
.. autofunction:: shephard.site.Site.remove_attribute


Site Track Functions
.......................
.. autofunction:: shephard.site.Site.get_track_values
.. autofunction:: shephard.site.Site.get_track_symbols

